@@ -3,8 +3,10 @@ This package contains all objects for sending Requests and waiting for the corre
 of specific KNX/IP Packets used for tunnelling connections.
 """
 # flake8: noqa
+from .authenticate import Authenticate
 from .connect import Connect
 from .connectionstate import ConnectionState
 from .disconnect import Disconnect
 from .request_response import RequestResponse
+from .session import Session
 from .tunnelling import Tunnelling
